import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DatabaseMigrationServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DatabaseMigrationServiceClient";
import { DescribeRecommendationLimitationsRequest, DescribeRecommendationLimitationsResponse } from "../models/models_0";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link DescribeRecommendationLimitationsCommand}.
 */
export interface DescribeRecommendationLimitationsCommandInput extends DescribeRecommendationLimitationsRequest {
}
/**
 * @public
 *
 * The output of {@link DescribeRecommendationLimitationsCommand}.
 */
export interface DescribeRecommendationLimitationsCommandOutput extends DescribeRecommendationLimitationsResponse, __MetadataBearer {
}
declare const DescribeRecommendationLimitationsCommand_base: {
    new (input: DescribeRecommendationLimitationsCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeRecommendationLimitationsCommandInput, DescribeRecommendationLimitationsCommandOutput, DatabaseMigrationServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [DescribeRecommendationLimitationsCommandInput]): import("@smithy/smithy-client").CommandImpl<DescribeRecommendationLimitationsCommandInput, DescribeRecommendationLimitationsCommandOutput, DatabaseMigrationServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns a paginated list of limitations for recommendations of target Amazon Web Services
 *             engines.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DatabaseMigrationServiceClient, DescribeRecommendationLimitationsCommand } from "@aws-sdk/client-database-migration-service"; // ES Modules import
 * // const { DatabaseMigrationServiceClient, DescribeRecommendationLimitationsCommand } = require("@aws-sdk/client-database-migration-service"); // CommonJS import
 * const client = new DatabaseMigrationServiceClient(config);
 * const input = { // DescribeRecommendationLimitationsRequest
 *   Filters: [ // FilterList
 *     { // Filter
 *       Name: "STRING_VALUE", // required
 *       Values: [ // FilterValueList // required
 *         "STRING_VALUE",
 *       ],
 *     },
 *   ],
 *   MaxRecords: Number("int"),
 *   NextToken: "STRING_VALUE",
 * };
 * const command = new DescribeRecommendationLimitationsCommand(input);
 * const response = await client.send(command);
 * // { // DescribeRecommendationLimitationsResponse
 * //   NextToken: "STRING_VALUE",
 * //   Limitations: [ // LimitationList
 * //     { // Limitation
 * //       DatabaseId: "STRING_VALUE",
 * //       EngineName: "STRING_VALUE",
 * //       Name: "STRING_VALUE",
 * //       Description: "STRING_VALUE",
 * //       Impact: "STRING_VALUE",
 * //       Type: "STRING_VALUE",
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param DescribeRecommendationLimitationsCommandInput - {@link DescribeRecommendationLimitationsCommandInput}
 * @returns {@link DescribeRecommendationLimitationsCommandOutput}
 * @see {@link DescribeRecommendationLimitationsCommandInput} for command's `input` shape.
 * @see {@link DescribeRecommendationLimitationsCommandOutput} for command's `response` shape.
 * @see {@link DatabaseMigrationServiceClientResolvedConfig | config} for DatabaseMigrationServiceClient's `config` shape.
 *
 * @throws {@link AccessDeniedFault} (client fault)
 *  <p>DMS was denied access to the endpoint. Check that the
 *             role is correctly configured.</p>
 *
 * @throws {@link InvalidResourceStateFault} (client fault)
 *  <p>The resource is in a state that prevents it from being used for database migration.</p>
 *
 * @throws {@link DatabaseMigrationServiceServiceException}
 * <p>Base exception class for all service exceptions from DatabaseMigrationService service.</p>
 *
 * @public
 */
export declare class DescribeRecommendationLimitationsCommand extends DescribeRecommendationLimitationsCommand_base {
}
