import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DatabaseMigrationServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DatabaseMigrationServiceClient";
import { DescribeReplicationConfigsMessage, DescribeReplicationConfigsResponse } from "../models/models_0";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link DescribeReplicationConfigsCommand}.
 */
export interface DescribeReplicationConfigsCommandInput extends DescribeReplicationConfigsMessage {
}
/**
 * @public
 *
 * The output of {@link DescribeReplicationConfigsCommand}.
 */
export interface DescribeReplicationConfigsCommandOutput extends DescribeReplicationConfigsResponse, __MetadataBearer {
}
declare const DescribeReplicationConfigsCommand_base: {
    new (input: DescribeReplicationConfigsCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeReplicationConfigsCommandInput, DescribeReplicationConfigsCommandOutput, DatabaseMigrationServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [DescribeReplicationConfigsCommandInput]): import("@smithy/smithy-client").CommandImpl<DescribeReplicationConfigsCommandInput, DescribeReplicationConfigsCommandOutput, DatabaseMigrationServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns one or more existing DMS Serverless replication configurations as a list of structures.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DatabaseMigrationServiceClient, DescribeReplicationConfigsCommand } from "@aws-sdk/client-database-migration-service"; // ES Modules import
 * // const { DatabaseMigrationServiceClient, DescribeReplicationConfigsCommand } = require("@aws-sdk/client-database-migration-service"); // CommonJS import
 * const client = new DatabaseMigrationServiceClient(config);
 * const input = { // DescribeReplicationConfigsMessage
 *   Filters: [ // FilterList
 *     { // Filter
 *       Name: "STRING_VALUE", // required
 *       Values: [ // FilterValueList // required
 *         "STRING_VALUE",
 *       ],
 *     },
 *   ],
 *   MaxRecords: Number("int"),
 *   Marker: "STRING_VALUE",
 * };
 * const command = new DescribeReplicationConfigsCommand(input);
 * const response = await client.send(command);
 * // { // DescribeReplicationConfigsResponse
 * //   Marker: "STRING_VALUE",
 * //   ReplicationConfigs: [ // ReplicationConfigList
 * //     { // ReplicationConfig
 * //       ReplicationConfigIdentifier: "STRING_VALUE",
 * //       ReplicationConfigArn: "STRING_VALUE",
 * //       SourceEndpointArn: "STRING_VALUE",
 * //       TargetEndpointArn: "STRING_VALUE",
 * //       ReplicationType: "full-load" || "cdc" || "full-load-and-cdc",
 * //       ComputeConfig: { // ComputeConfig
 * //         AvailabilityZone: "STRING_VALUE",
 * //         DnsNameServers: "STRING_VALUE",
 * //         KmsKeyId: "STRING_VALUE",
 * //         MaxCapacityUnits: Number("int"),
 * //         MinCapacityUnits: Number("int"),
 * //         MultiAZ: true || false,
 * //         PreferredMaintenanceWindow: "STRING_VALUE",
 * //         ReplicationSubnetGroupId: "STRING_VALUE",
 * //         VpcSecurityGroupIds: [ // StringList
 * //           "STRING_VALUE",
 * //         ],
 * //       },
 * //       ReplicationSettings: "STRING_VALUE",
 * //       SupplementalSettings: "STRING_VALUE",
 * //       TableMappings: "STRING_VALUE",
 * //       ReplicationConfigCreateTime: new Date("TIMESTAMP"),
 * //       ReplicationConfigUpdateTime: new Date("TIMESTAMP"),
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param DescribeReplicationConfigsCommandInput - {@link DescribeReplicationConfigsCommandInput}
 * @returns {@link DescribeReplicationConfigsCommandOutput}
 * @see {@link DescribeReplicationConfigsCommandInput} for command's `input` shape.
 * @see {@link DescribeReplicationConfigsCommandOutput} for command's `response` shape.
 * @see {@link DatabaseMigrationServiceClientResolvedConfig | config} for DatabaseMigrationServiceClient's `config` shape.
 *
 * @throws {@link ResourceNotFoundFault} (client fault)
 *  <p>The resource could not be found.</p>
 *
 * @throws {@link DatabaseMigrationServiceServiceException}
 * <p>Base exception class for all service exceptions from DatabaseMigrationService service.</p>
 *
 * @public
 */
export declare class DescribeReplicationConfigsCommand extends DescribeReplicationConfigsCommand_base {
}
