import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DatabaseMigrationServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DatabaseMigrationServiceClient";
import { StartRecommendationsRequest } from "../models/models_1";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link StartRecommendationsCommand}.
 */
export interface StartRecommendationsCommandInput extends StartRecommendationsRequest {
}
/**
 * @public
 *
 * The output of {@link StartRecommendationsCommand}.
 */
export interface StartRecommendationsCommandOutput extends __MetadataBearer {
}
declare const StartRecommendationsCommand_base: {
    new (input: StartRecommendationsCommandInput): import("@smithy/smithy-client").CommandImpl<StartRecommendationsCommandInput, StartRecommendationsCommandOutput, DatabaseMigrationServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: StartRecommendationsCommandInput): import("@smithy/smithy-client").CommandImpl<StartRecommendationsCommandInput, StartRecommendationsCommandOutput, DatabaseMigrationServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Starts the analysis of your source database to provide recommendations of target
 *             engines.</p>
 *          <p>You can create recommendations for multiple source databases using <a href="https://docs.aws.amazon.com/dms/latest/APIReference/API_BatchStartRecommendations.html">BatchStartRecommendations</a>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DatabaseMigrationServiceClient, StartRecommendationsCommand } from "@aws-sdk/client-database-migration-service"; // ES Modules import
 * // const { DatabaseMigrationServiceClient, StartRecommendationsCommand } = require("@aws-sdk/client-database-migration-service"); // CommonJS import
 * const client = new DatabaseMigrationServiceClient(config);
 * const input = { // StartRecommendationsRequest
 *   DatabaseId: "STRING_VALUE", // required
 *   Settings: { // RecommendationSettings
 *     InstanceSizingType: "STRING_VALUE", // required
 *     WorkloadType: "STRING_VALUE", // required
 *   },
 * };
 * const command = new StartRecommendationsCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param StartRecommendationsCommandInput - {@link StartRecommendationsCommandInput}
 * @returns {@link StartRecommendationsCommandOutput}
 * @see {@link StartRecommendationsCommandInput} for command's `input` shape.
 * @see {@link StartRecommendationsCommandOutput} for command's `response` shape.
 * @see {@link DatabaseMigrationServiceClientResolvedConfig | config} for DatabaseMigrationServiceClient's `config` shape.
 *
 * @throws {@link AccessDeniedFault} (client fault)
 *  <p>DMS was denied access to the endpoint. Check that the
 *             role is correctly configured.</p>
 *
 * @throws {@link InvalidResourceStateFault} (client fault)
 *  <p>The resource is in a state that prevents it from being used for database migration.</p>
 *
 * @throws {@link ResourceNotFoundFault} (client fault)
 *  <p>The resource could not be found.</p>
 *
 * @throws {@link DatabaseMigrationServiceServiceException}
 * <p>Base exception class for all service exceptions from DatabaseMigrationService service.</p>
 *
 * @public
 */
export declare class StartRecommendationsCommand extends StartRecommendationsCommand_base {
}
