import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { DatabaseMigrationServiceServiceException as __BaseException } from "./DatabaseMigrationServiceServiceException";
export declare class AccessDeniedFault extends __BaseException {
  readonly name: "AccessDeniedFault";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<AccessDeniedFault, __BaseException>);
}
export interface AccountQuota {
  AccountQuotaName?: string;
  Used?: number;
  Max?: number;
}
export interface Tag {
  Key?: string;
  Value?: string;
  ResourceArn?: string;
}
export interface AddTagsToResourceMessage {
  ResourceArn: string | undefined;
  Tags: Tag[] | undefined;
}
export interface AddTagsToResourceResponse {}
export declare class ResourceNotFoundFault extends __BaseException {
  readonly name: "ResourceNotFoundFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ResourceNotFoundFault, __BaseException>
  );
}
export interface ApplyPendingMaintenanceActionMessage {
  ReplicationInstanceArn: string | undefined;
  ApplyAction: string | undefined;
  OptInType: string | undefined;
}
export interface PendingMaintenanceAction {
  Action?: string;
  AutoAppliedAfterDate?: Date;
  ForcedApplyDate?: Date;
  OptInStatus?: string;
  CurrentApplyDate?: Date;
  Description?: string;
}
export interface ResourcePendingMaintenanceActions {
  ResourceIdentifier?: string;
  PendingMaintenanceActionDetails?: PendingMaintenanceAction[];
}
export interface ApplyPendingMaintenanceActionResponse {
  ResourcePendingMaintenanceActions?: ResourcePendingMaintenanceActions;
}
export interface RecommendationSettings {
  InstanceSizingType: string | undefined;
  WorkloadType: string | undefined;
}
export interface StartRecommendationsRequestEntry {
  DatabaseId: string | undefined;
  Settings: RecommendationSettings | undefined;
}
export interface BatchStartRecommendationsRequest {
  Data?: StartRecommendationsRequestEntry[];
}
export interface BatchStartRecommendationsErrorEntry {
  DatabaseId?: string;
  Message?: string;
  Code?: string;
}
export interface BatchStartRecommendationsResponse {
  ErrorEntries?: BatchStartRecommendationsErrorEntry[];
}
export declare class InvalidResourceStateFault extends __BaseException {
  readonly name: "InvalidResourceStateFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidResourceStateFault, __BaseException>
  );
}
export interface CancelReplicationTaskAssessmentRunMessage {
  ReplicationTaskAssessmentRunArn: string | undefined;
}
export interface ReplicationTaskAssessmentRunProgress {
  IndividualAssessmentCount?: number;
  IndividualAssessmentCompletedCount?: number;
}
export interface ReplicationTaskAssessmentRun {
  ReplicationTaskAssessmentRunArn?: string;
  ReplicationTaskArn?: string;
  Status?: string;
  ReplicationTaskAssessmentRunCreationDate?: Date;
  AssessmentProgress?: ReplicationTaskAssessmentRunProgress;
  LastFailureMessage?: string;
  ServiceAccessRoleArn?: string;
  ResultLocationBucket?: string;
  ResultLocationFolder?: string;
  ResultEncryptionMode?: string;
  ResultKmsKeyArn?: string;
  AssessmentRunName?: string;
}
export interface CancelReplicationTaskAssessmentRunResponse {
  ReplicationTaskAssessmentRun?: ReplicationTaskAssessmentRun;
}
export declare const DmsSslModeValue: {
  readonly NONE: "none";
  readonly REQUIRE: "require";
  readonly VERIFY_CA: "verify-ca";
  readonly VERIFY_FULL: "verify-full";
};
export type DmsSslModeValue =
  (typeof DmsSslModeValue)[keyof typeof DmsSslModeValue];
export interface DocDbDataProviderSettings {
  ServerName?: string;
  Port?: number;
  DatabaseName?: string;
  SslMode?: DmsSslModeValue;
  CertificateArn?: string;
}
export interface MariaDbDataProviderSettings {
  ServerName?: string;
  Port?: number;
  SslMode?: DmsSslModeValue;
  CertificateArn?: string;
}
export interface MicrosoftSqlServerDataProviderSettings {
  ServerName?: string;
  Port?: number;
  DatabaseName?: string;
  SslMode?: DmsSslModeValue;
  CertificateArn?: string;
}
export declare const AuthMechanismValue: {
  readonly DEFAULT: "default";
  readonly MONGODB_CR: "mongodb_cr";
  readonly SCRAM_SHA_1: "scram_sha_1";
};
export type AuthMechanismValue =
  (typeof AuthMechanismValue)[keyof typeof AuthMechanismValue];
export declare const AuthTypeValue: {
  readonly NO: "no";
  readonly PASSWORD: "password";
};
export type AuthTypeValue = (typeof AuthTypeValue)[keyof typeof AuthTypeValue];
export interface MongoDbDataProviderSettings {
  ServerName?: string;
  Port?: number;
  DatabaseName?: string;
  SslMode?: DmsSslModeValue;
  CertificateArn?: string;
  AuthType?: AuthTypeValue;
  AuthSource?: string;
  AuthMechanism?: AuthMechanismValue;
}
export interface MySqlDataProviderSettings {
  ServerName?: string;
  Port?: number;
  SslMode?: DmsSslModeValue;
  CertificateArn?: string;
}
export interface OracleDataProviderSettings {
  ServerName?: string;
  Port?: number;
  DatabaseName?: string;
  SslMode?: DmsSslModeValue;
  CertificateArn?: string;
  AsmServer?: string;
  SecretsManagerOracleAsmSecretId?: string;
  SecretsManagerOracleAsmAccessRoleArn?: string;
  SecretsManagerSecurityDbEncryptionSecretId?: string;
  SecretsManagerSecurityDbEncryptionAccessRoleArn?: string;
}
export interface PostgreSqlDataProviderSettings {
  ServerName?: string;
  Port?: number;
  DatabaseName?: string;
  SslMode?: DmsSslModeValue;
  CertificateArn?: string;
}
export interface RedshiftDataProviderSettings {
  ServerName?: string;
  Port?: number;
  DatabaseName?: string;
}
export type DataProviderSettings =
  | DataProviderSettings.DocDbSettingsMember
  | DataProviderSettings.MariaDbSettingsMember
  | DataProviderSettings.MicrosoftSqlServerSettingsMember
  | DataProviderSettings.MongoDbSettingsMember
  | DataProviderSettings.MySqlSettingsMember
  | DataProviderSettings.OracleSettingsMember
  | DataProviderSettings.PostgreSqlSettingsMember
  | DataProviderSettings.RedshiftSettingsMember
  | DataProviderSettings.$UnknownMember;
export declare namespace DataProviderSettings {
  interface RedshiftSettingsMember {
    RedshiftSettings: RedshiftDataProviderSettings;
    PostgreSqlSettings?: never;
    MySqlSettings?: never;
    OracleSettings?: never;
    MicrosoftSqlServerSettings?: never;
    DocDbSettings?: never;
    MariaDbSettings?: never;
    MongoDbSettings?: never;
    $unknown?: never;
  }
  interface PostgreSqlSettingsMember {
    RedshiftSettings?: never;
    PostgreSqlSettings: PostgreSqlDataProviderSettings;
    MySqlSettings?: never;
    OracleSettings?: never;
    MicrosoftSqlServerSettings?: never;
    DocDbSettings?: never;
    MariaDbSettings?: never;
    MongoDbSettings?: never;
    $unknown?: never;
  }
  interface MySqlSettingsMember {
    RedshiftSettings?: never;
    PostgreSqlSettings?: never;
    MySqlSettings: MySqlDataProviderSettings;
    OracleSettings?: never;
    MicrosoftSqlServerSettings?: never;
    DocDbSettings?: never;
    MariaDbSettings?: never;
    MongoDbSettings?: never;
    $unknown?: never;
  }
  interface OracleSettingsMember {
    RedshiftSettings?: never;
    PostgreSqlSettings?: never;
    MySqlSettings?: never;
    OracleSettings: OracleDataProviderSettings;
    MicrosoftSqlServerSettings?: never;
    DocDbSettings?: never;
    MariaDbSettings?: never;
    MongoDbSettings?: never;
    $unknown?: never;
  }
  interface MicrosoftSqlServerSettingsMember {
    RedshiftSettings?: never;
    PostgreSqlSettings?: never;
    MySqlSettings?: never;
    OracleSettings?: never;
    MicrosoftSqlServerSettings: MicrosoftSqlServerDataProviderSettings;
    DocDbSettings?: never;
    MariaDbSettings?: never;
    MongoDbSettings?: never;
    $unknown?: never;
  }
  interface DocDbSettingsMember {
    RedshiftSettings?: never;
    PostgreSqlSettings?: never;
    MySqlSettings?: never;
    OracleSettings?: never;
    MicrosoftSqlServerSettings?: never;
    DocDbSettings: DocDbDataProviderSettings;
    MariaDbSettings?: never;
    MongoDbSettings?: never;
    $unknown?: never;
  }
  interface MariaDbSettingsMember {
    RedshiftSettings?: never;
    PostgreSqlSettings?: never;
    MySqlSettings?: never;
    OracleSettings?: never;
    MicrosoftSqlServerSettings?: never;
    DocDbSettings?: never;
    MariaDbSettings: MariaDbDataProviderSettings;
    MongoDbSettings?: never;
    $unknown?: never;
  }
  interface MongoDbSettingsMember {
    RedshiftSettings?: never;
    PostgreSqlSettings?: never;
    MySqlSettings?: never;
    OracleSettings?: never;
    MicrosoftSqlServerSettings?: never;
    DocDbSettings?: never;
    MariaDbSettings?: never;
    MongoDbSettings: MongoDbDataProviderSettings;
    $unknown?: never;
  }
  interface $UnknownMember {
    RedshiftSettings?: never;
    PostgreSqlSettings?: never;
    MySqlSettings?: never;
    OracleSettings?: never;
    MicrosoftSqlServerSettings?: never;
    DocDbSettings?: never;
    MariaDbSettings?: never;
    MongoDbSettings?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    RedshiftSettings: (value: RedshiftDataProviderSettings) => T;
    PostgreSqlSettings: (value: PostgreSqlDataProviderSettings) => T;
    MySqlSettings: (value: MySqlDataProviderSettings) => T;
    OracleSettings: (value: OracleDataProviderSettings) => T;
    MicrosoftSqlServerSettings: (
      value: MicrosoftSqlServerDataProviderSettings
    ) => T;
    DocDbSettings: (value: DocDbDataProviderSettings) => T;
    MariaDbSettings: (value: MariaDbDataProviderSettings) => T;
    MongoDbSettings: (value: MongoDbDataProviderSettings) => T;
    _: (name: string, value: any) => T;
  }
  const visit: <T>(value: DataProviderSettings, visitor: Visitor<T>) => T;
}
export interface CreateDataProviderMessage {
  DataProviderName?: string;
  Description?: string;
  Engine: string | undefined;
  Settings: DataProviderSettings | undefined;
  Tags?: Tag[];
}
export interface DataProvider {
  DataProviderName?: string;
  DataProviderArn?: string;
  DataProviderCreationTime?: Date;
  Description?: string;
  Engine?: string;
  Settings?: DataProviderSettings;
}
export interface CreateDataProviderResponse {
  DataProvider?: DataProvider;
}
export declare class ResourceAlreadyExistsFault extends __BaseException {
  readonly name: "ResourceAlreadyExistsFault";
  readonly $fault: "client";
  resourceArn?: string;
  constructor(
    opts: __ExceptionOptionType<ResourceAlreadyExistsFault, __BaseException>
  );
}
export declare class ResourceQuotaExceededFault extends __BaseException {
  readonly name: "ResourceQuotaExceededFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ResourceQuotaExceededFault, __BaseException>
  );
}
export interface DmsTransferSettings {
  ServiceAccessRoleArn?: string;
  BucketName?: string;
}
export declare const NestingLevelValue: {
  readonly NONE: "none";
  readonly ONE: "one";
};
export type NestingLevelValue =
  (typeof NestingLevelValue)[keyof typeof NestingLevelValue];
export interface DocDbSettings {
  Username?: string;
  Password?: string;
  ServerName?: string;
  Port?: number;
  DatabaseName?: string;
  NestingLevel?: NestingLevelValue;
  ExtractDocId?: boolean;
  DocsToInvestigate?: number;
  KmsKeyId?: string;
  SecretsManagerAccessRoleArn?: string;
  SecretsManagerSecretId?: string;
  UseUpdateLookUp?: boolean;
  ReplicateShardCollections?: boolean;
}
export interface DynamoDbSettings {
  ServiceAccessRoleArn: string | undefined;
}
export interface ElasticsearchSettings {
  ServiceAccessRoleArn: string | undefined;
  EndpointUri: string | undefined;
  FullLoadErrorPercentage?: number;
  ErrorRetryDuration?: number;
  UseNewMappingType?: boolean;
}
export declare const ReplicationEndpointTypeValue: {
  readonly SOURCE: "source";
  readonly TARGET: "target";
};
export type ReplicationEndpointTypeValue =
  (typeof ReplicationEndpointTypeValue)[keyof typeof ReplicationEndpointTypeValue];
export declare const TargetDbType: {
  readonly MULTIPLE_DATABASES: "multiple-databases";
  readonly SPECIFIC_DATABASE: "specific-database";
};
export type TargetDbType = (typeof TargetDbType)[keyof typeof TargetDbType];
export interface GcpMySQLSettings {
  AfterConnectScript?: string;
  CleanSourceMetadataOnMismatch?: boolean;
  DatabaseName?: string;
  EventsPollInterval?: number;
  TargetDbType?: TargetDbType;
  MaxFileSize?: number;
  ParallelLoadThreads?: number;
  Password?: string;
  Port?: number;
  ServerName?: string;
  ServerTimezone?: string;
  Username?: string;
  SecretsManagerAccessRoleArn?: string;
  SecretsManagerSecretId?: string;
}
export interface IBMDb2Settings {
  DatabaseName?: string;
  Password?: string;
  Port?: number;
  ServerName?: string;
  SetDataCaptureChanges?: boolean;
  CurrentLsn?: string;
  MaxKBytesPerRead?: number;
  Username?: string;
  SecretsManagerAccessRoleArn?: string;
  SecretsManagerSecretId?: string;
  LoadTimeout?: number;
  WriteBufferSize?: number;
  MaxFileSize?: number;
  KeepCsvFiles?: boolean;
}
export declare const MessageFormatValue: {
  readonly JSON: "json";
  readonly JSON_UNFORMATTED: "json-unformatted";
};
export type MessageFormatValue =
  (typeof MessageFormatValue)[keyof typeof MessageFormatValue];
export declare const KafkaSaslMechanism: {
  readonly PLAIN: "plain";
  readonly SCRAM_SHA_512: "scram-sha-512";
};
export type KafkaSaslMechanism =
  (typeof KafkaSaslMechanism)[keyof typeof KafkaSaslMechanism];
export declare const KafkaSecurityProtocol: {
  readonly PLAINTEXT: "plaintext";
  readonly SASL_SSL: "sasl-ssl";
  readonly SSL_AUTHENTICATION: "ssl-authentication";
  readonly SSL_ENCRYPTION: "ssl-encryption";
};
export type KafkaSecurityProtocol =
  (typeof KafkaSecurityProtocol)[keyof typeof KafkaSecurityProtocol];
export declare const KafkaSslEndpointIdentificationAlgorithm: {
  readonly HTTPS: "https";
  readonly NONE: "none";
};
export type KafkaSslEndpointIdentificationAlgorithm =
  (typeof KafkaSslEndpointIdentificationAlgorithm)[keyof typeof KafkaSslEndpointIdentificationAlgorithm];
export interface KafkaSettings {
  Broker?: string;
  Topic?: string;
  MessageFormat?: MessageFormatValue;
  IncludeTransactionDetails?: boolean;
  IncludePartitionValue?: boolean;
  PartitionIncludeSchemaTable?: boolean;
  IncludeTableAlterOperations?: boolean;
  IncludeControlDetails?: boolean;
  MessageMaxBytes?: number;
  IncludeNullAndEmpty?: boolean;
  SecurityProtocol?: KafkaSecurityProtocol;
  SslClientCertificateArn?: string;
  SslClientKeyArn?: string;
  SslClientKeyPassword?: string;
  SslCaCertificateArn?: string;
  SaslUsername?: string;
  SaslPassword?: string;
  NoHexPrefix?: boolean;
  SaslMechanism?: KafkaSaslMechanism;
  SslEndpointIdentificationAlgorithm?: KafkaSslEndpointIdentificationAlgorithm;
}
export interface KinesisSettings {
  StreamArn?: string;
  MessageFormat?: MessageFormatValue;
  ServiceAccessRoleArn?: string;
  IncludeTransactionDetails?: boolean;
  IncludePartitionValue?: boolean;
  PartitionIncludeSchemaTable?: boolean;
  IncludeTableAlterOperations?: boolean;
  IncludeControlDetails?: boolean;
  IncludeNullAndEmpty?: boolean;
  NoHexPrefix?: boolean;
}
export declare const SafeguardPolicy: {
  readonly EXCLUSIVE_AUTOMATIC_TRUNCATION: "exclusive-automatic-truncation";
  readonly RELY_ON_SQL_SERVER_REPLICATION_AGENT: "rely-on-sql-server-replication-agent";
  readonly SHARED_AUTOMATIC_TRUNCATION: "shared-automatic-truncation";
};
export type SafeguardPolicy =
  (typeof SafeguardPolicy)[keyof typeof SafeguardPolicy];
export declare const TlogAccessMode: {
  readonly BackupOnly: "BackupOnly";
  readonly PreferBackup: "PreferBackup";
  readonly PreferTlog: "PreferTlog";
  readonly TlogOnly: "TlogOnly";
};
export type TlogAccessMode =
  (typeof TlogAccessMode)[keyof typeof TlogAccessMode];
export interface MicrosoftSQLServerSettings {
  Port?: number;
  BcpPacketSize?: number;
  DatabaseName?: string;
  ControlTablesFileGroup?: string;
  Password?: string;
  QuerySingleAlwaysOnNode?: boolean;
  ReadBackupOnly?: boolean;
  SafeguardPolicy?: SafeguardPolicy;
  ServerName?: string;
  Username?: string;
  UseBcpFullLoad?: boolean;
  UseThirdPartyBackupDevice?: boolean;
  SecretsManagerAccessRoleArn?: string;
  SecretsManagerSecretId?: string;
  TrimSpaceInChar?: boolean;
  TlogAccessMode?: TlogAccessMode;
  ForceLobLookup?: boolean;
}
export interface MongoDbSettings {
  Username?: string;
  Password?: string;
  ServerName?: string;
  Port?: number;
  DatabaseName?: string;
  AuthType?: AuthTypeValue;
  AuthMechanism?: AuthMechanismValue;
  NestingLevel?: NestingLevelValue;
  ExtractDocId?: string;
  DocsToInvestigate?: string;
  AuthSource?: string;
  KmsKeyId?: string;
  SecretsManagerAccessRoleArn?: string;
  SecretsManagerSecretId?: string;
  UseUpdateLookUp?: boolean;
  ReplicateShardCollections?: boolean;
}
export interface MySQLSettings {
  AfterConnectScript?: string;
  CleanSourceMetadataOnMismatch?: boolean;
  DatabaseName?: string;
  EventsPollInterval?: number;
  TargetDbType?: TargetDbType;
  MaxFileSize?: number;
  ParallelLoadThreads?: number;
  Password?: string;
  Port?: number;
  ServerName?: string;
  ServerTimezone?: string;
  Username?: string;
  SecretsManagerAccessRoleArn?: string;
  SecretsManagerSecretId?: string;
  ExecuteTimeout?: number;
}
export interface NeptuneSettings {
  ServiceAccessRoleArn?: string;
  S3BucketName: string | undefined;
  S3BucketFolder: string | undefined;
  ErrorRetryDuration?: number;
  MaxFileSize?: number;
  MaxRetryCount?: number;
  IamAuthEnabled?: boolean;
}
export declare const CharLengthSemantics: {
  readonly BYTE: "byte";
  readonly CHAR: "char";
  readonly DEFAULT: "default";
};
export type CharLengthSemantics =
  (typeof CharLengthSemantics)[keyof typeof CharLengthSemantics];
export interface OracleSettings {
  AddSupplementalLogging?: boolean;
  ArchivedLogDestId?: number;
  AdditionalArchivedLogDestId?: number;
  ExtraArchivedLogDestIds?: number[];
  AllowSelectNestedTables?: boolean;
  ParallelAsmReadThreads?: number;
  ReadAheadBlocks?: number;
  AccessAlternateDirectly?: boolean;
  UseAlternateFolderForOnline?: boolean;
  OraclePathPrefix?: string;
  UsePathPrefix?: string;
  ReplacePathPrefix?: boolean;
  EnableHomogenousTablespace?: boolean;
  DirectPathNoLog?: boolean;
  ArchivedLogsOnly?: boolean;
  AsmPassword?: string;
  AsmServer?: string;
  AsmUser?: string;
  CharLengthSemantics?: CharLengthSemantics;
  DatabaseName?: string;
  DirectPathParallelLoad?: boolean;
  FailTasksOnLobTruncation?: boolean;
  NumberDatatypeScale?: number;
  Password?: string;
  Port?: number;
  ReadTableSpaceName?: boolean;
  RetryInterval?: number;
  SecurityDbEncryption?: string;
  SecurityDbEncryptionName?: string;
  ServerName?: string;
  SpatialDataOptionToGeoJsonFunctionName?: string;
  StandbyDelayTime?: number;
  Username?: string;
  UseBFile?: boolean;
  UseDirectPathFullLoad?: boolean;
  UseLogminerReader?: boolean;
  SecretsManagerAccessRoleArn?: string;
  SecretsManagerSecretId?: string;
  SecretsManagerOracleAsmAccessRoleArn?: string;
  SecretsManagerOracleAsmSecretId?: string;
  TrimSpaceInChar?: boolean;
  ConvertTimestampWithZoneToUTC?: boolean;
  OpenTransactionWindow?: number;
}
export declare const DatabaseMode: {
  readonly BABELFISH: "babelfish";
  readonly DEFAULT: "default";
};
export type DatabaseMode = (typeof DatabaseMode)[keyof typeof DatabaseMode];
export declare const LongVarcharMappingType: {
  readonly CLOB: "clob";
  readonly NCLOB: "nclob";
  readonly WSTRING: "wstring";
};
export type LongVarcharMappingType =
  (typeof LongVarcharMappingType)[keyof typeof LongVarcharMappingType];
export declare const PluginNameValue: {
  readonly NO_PREFERENCE: "no-preference";
  readonly PGLOGICAL: "pglogical";
  readonly TEST_DECODING: "test-decoding";
};
export type PluginNameValue =
  (typeof PluginNameValue)[keyof typeof PluginNameValue];
export interface PostgreSQLSettings {
  AfterConnectScript?: string;
  CaptureDdls?: boolean;
  MaxFileSize?: number;
  DatabaseName?: string;
  DdlArtifactsSchema?: string;
  ExecuteTimeout?: number;
  FailTasksOnLobTruncation?: boolean;
  HeartbeatEnable?: boolean;
  HeartbeatSchema?: string;
  HeartbeatFrequency?: number;
  Password?: string;
  Port?: number;
  ServerName?: string;
  Username?: string;
  SlotName?: string;
  PluginName?: PluginNameValue;
  SecretsManagerAccessRoleArn?: string;
  SecretsManagerSecretId?: string;
  TrimSpaceInChar?: boolean;
  MapBooleanAsBoolean?: boolean;
  MapJsonbAsClob?: boolean;
  MapLongVarcharAs?: LongVarcharMappingType;
  DatabaseMode?: DatabaseMode;
  BabelfishDatabaseName?: string;
}
export declare const RedisAuthTypeValue: {
  readonly AUTH_ROLE: "auth-role";
  readonly AUTH_TOKEN: "auth-token";
  readonly NONE: "none";
};
export type RedisAuthTypeValue =
  (typeof RedisAuthTypeValue)[keyof typeof RedisAuthTypeValue];
export declare const SslSecurityProtocolValue: {
  readonly PLAINTEXT: "plaintext";
  readonly SSL_ENCRYPTION: "ssl-encryption";
};
export type SslSecurityProtocolValue =
  (typeof SslSecurityProtocolValue)[keyof typeof SslSecurityProtocolValue];
export interface RedisSettings {
  ServerName: string | undefined;
  Port: number | undefined;
  SslSecurityProtocol?: SslSecurityProtocolValue;
  AuthType?: RedisAuthTypeValue;
  AuthUserName?: string;
  AuthPassword?: string;
  SslCaCertificateArn?: string;
}
export declare const EncryptionModeValue: {
  readonly SSE_KMS: "sse-kms";
  readonly SSE_S3: "sse-s3";
};
export type EncryptionModeValue =
  (typeof EncryptionModeValue)[keyof typeof EncryptionModeValue];
export interface RedshiftSettings {
  AcceptAnyDate?: boolean;
  AfterConnectScript?: string;
  BucketFolder?: string;
  BucketName?: string;
  CaseSensitiveNames?: boolean;
  CompUpdate?: boolean;
  ConnectionTimeout?: number;
  DatabaseName?: string;
  DateFormat?: string;
  EmptyAsNull?: boolean;
  EncryptionMode?: EncryptionModeValue;
  ExplicitIds?: boolean;
  FileTransferUploadStreams?: number;
  LoadTimeout?: number;
  MaxFileSize?: number;
  Password?: string;
  Port?: number;
  RemoveQuotes?: boolean;
  ReplaceInvalidChars?: string;
  ReplaceChars?: string;
  ServerName?: string;
  ServiceAccessRoleArn?: string;
  ServerSideEncryptionKmsKeyId?: string;
  TimeFormat?: string;
  TrimBlanks?: boolean;
  TruncateColumns?: boolean;
  Username?: string;
  WriteBufferSize?: number;
  SecretsManagerAccessRoleArn?: string;
  SecretsManagerSecretId?: string;
  MapBooleanAsBoolean?: boolean;
}
export declare const CannedAclForObjectsValue: {
  readonly AUTHENTICATED_READ: "authenticated-read";
  readonly AWS_EXEC_READ: "aws-exec-read";
  readonly BUCKET_OWNER_FULL_CONTROL: "bucket-owner-full-control";
  readonly BUCKET_OWNER_READ: "bucket-owner-read";
  readonly NONE: "none";
  readonly PRIVATE: "private";
  readonly PUBLIC_READ: "public-read";
  readonly PUBLIC_READ_WRITE: "public-read-write";
};
export type CannedAclForObjectsValue =
  (typeof CannedAclForObjectsValue)[keyof typeof CannedAclForObjectsValue];
export declare const CompressionTypeValue: {
  readonly GZIP: "gzip";
  readonly NONE: "none";
};
export type CompressionTypeValue =
  (typeof CompressionTypeValue)[keyof typeof CompressionTypeValue];
export declare const DataFormatValue: {
  readonly CSV: "csv";
  readonly PARQUET: "parquet";
};
export type DataFormatValue =
  (typeof DataFormatValue)[keyof typeof DataFormatValue];
export declare const DatePartitionDelimiterValue: {
  readonly DASH: "DASH";
  readonly NONE: "NONE";
  readonly SLASH: "SLASH";
  readonly UNDERSCORE: "UNDERSCORE";
};
export type DatePartitionDelimiterValue =
  (typeof DatePartitionDelimiterValue)[keyof typeof DatePartitionDelimiterValue];
export declare const DatePartitionSequenceValue: {
  readonly DDMMYYYY: "DDMMYYYY";
  readonly MMYYYYDD: "MMYYYYDD";
  readonly YYYYMM: "YYYYMM";
  readonly YYYYMMDD: "YYYYMMDD";
  readonly YYYYMMDDHH: "YYYYMMDDHH";
};
export type DatePartitionSequenceValue =
  (typeof DatePartitionSequenceValue)[keyof typeof DatePartitionSequenceValue];
export declare const EncodingTypeValue: {
  readonly PLAIN: "plain";
  readonly PLAIN_DICTIONARY: "plain-dictionary";
  readonly RLE_DICTIONARY: "rle-dictionary";
};
export type EncodingTypeValue =
  (typeof EncodingTypeValue)[keyof typeof EncodingTypeValue];
export declare const ParquetVersionValue: {
  readonly PARQUET_1_0: "parquet-1-0";
  readonly PARQUET_2_0: "parquet-2-0";
};
export type ParquetVersionValue =
  (typeof ParquetVersionValue)[keyof typeof ParquetVersionValue];
export interface S3Settings {
  ServiceAccessRoleArn?: string;
  ExternalTableDefinition?: string;
  CsvRowDelimiter?: string;
  CsvDelimiter?: string;
  BucketFolder?: string;
  BucketName?: string;
  CompressionType?: CompressionTypeValue;
  EncryptionMode?: EncryptionModeValue;
  ServerSideEncryptionKmsKeyId?: string;
  DataFormat?: DataFormatValue;
  EncodingType?: EncodingTypeValue;
  DictPageSizeLimit?: number;
  RowGroupLength?: number;
  DataPageSize?: number;
  ParquetVersion?: ParquetVersionValue;
  EnableStatistics?: boolean;
  IncludeOpForFullLoad?: boolean;
  CdcInsertsOnly?: boolean;
  TimestampColumnName?: string;
  ParquetTimestampInMillisecond?: boolean;
  CdcInsertsAndUpdates?: boolean;
  DatePartitionEnabled?: boolean;
  DatePartitionSequence?: DatePartitionSequenceValue;
  DatePartitionDelimiter?: DatePartitionDelimiterValue;
  UseCsvNoSupValue?: boolean;
  CsvNoSupValue?: string;
  PreserveTransactions?: boolean;
  CdcPath?: string;
  UseTaskStartTimeForFullLoadTimestamp?: boolean;
  CannedAclForObjects?: CannedAclForObjectsValue;
  AddColumnName?: boolean;
  CdcMaxBatchInterval?: number;
  CdcMinFileSize?: number;
  CsvNullValue?: string;
  IgnoreHeaderRows?: number;
  MaxFileSize?: number;
  Rfc4180?: boolean;
  DatePartitionTimezone?: string;
  AddTrailingPaddingCharacter?: boolean;
  ExpectedBucketOwner?: string;
  GlueCatalogGeneration?: boolean;
}
export interface SybaseSettings {
  DatabaseName?: string;
  Password?: string;
  Port?: number;
  ServerName?: string;
  Username?: string;
  SecretsManagerAccessRoleArn?: string;
  SecretsManagerSecretId?: string;
}
export interface TimestreamSettings {
  DatabaseName: string | undefined;
  MemoryDuration: number | undefined;
  MagneticDuration: number | undefined;
  CdcInsertsAndUpdates?: boolean;
  EnableMagneticStoreWrites?: boolean;
}
export interface CreateEndpointMessage {
  EndpointIdentifier: string | undefined;
  EndpointType: ReplicationEndpointTypeValue | undefined;
  EngineName: string | undefined;
  Username?: string;
  Password?: string;
  ServerName?: string;
  Port?: number;
  DatabaseName?: string;
  ExtraConnectionAttributes?: string;
  KmsKeyId?: string;
  Tags?: Tag[];
  CertificateArn?: string;
  SslMode?: DmsSslModeValue;
  ServiceAccessRoleArn?: string;
  ExternalTableDefinition?: string;
  DynamoDbSettings?: DynamoDbSettings;
  S3Settings?: S3Settings;
  DmsTransferSettings?: DmsTransferSettings;
  MongoDbSettings?: MongoDbSettings;
  KinesisSettings?: KinesisSettings;
  KafkaSettings?: KafkaSettings;
  ElasticsearchSettings?: ElasticsearchSettings;
  NeptuneSettings?: NeptuneSettings;
  RedshiftSettings?: RedshiftSettings;
  PostgreSQLSettings?: PostgreSQLSettings;
  MySQLSettings?: MySQLSettings;
  OracleSettings?: OracleSettings;
  SybaseSettings?: SybaseSettings;
  MicrosoftSQLServerSettings?: MicrosoftSQLServerSettings;
  IBMDb2Settings?: IBMDb2Settings;
  ResourceIdentifier?: string;
  DocDbSettings?: DocDbSettings;
  RedisSettings?: RedisSettings;
  GcpMySQLSettings?: GcpMySQLSettings;
  TimestreamSettings?: TimestreamSettings;
}
export interface Endpoint {
  EndpointIdentifier?: string;
  EndpointType?: ReplicationEndpointTypeValue;
  EngineName?: string;
  EngineDisplayName?: string;
  Username?: string;
  ServerName?: string;
  Port?: number;
  DatabaseName?: string;
  ExtraConnectionAttributes?: string;
  Status?: string;
  KmsKeyId?: string;
  EndpointArn?: string;
  CertificateArn?: string;
  SslMode?: DmsSslModeValue;
  ServiceAccessRoleArn?: string;
  ExternalTableDefinition?: string;
  ExternalId?: string;
  DynamoDbSettings?: DynamoDbSettings;
  S3Settings?: S3Settings;
  DmsTransferSettings?: DmsTransferSettings;
  MongoDbSettings?: MongoDbSettings;
  KinesisSettings?: KinesisSettings;
  KafkaSettings?: KafkaSettings;
  ElasticsearchSettings?: ElasticsearchSettings;
  NeptuneSettings?: NeptuneSettings;
  RedshiftSettings?: RedshiftSettings;
  PostgreSQLSettings?: PostgreSQLSettings;
  MySQLSettings?: MySQLSettings;
  OracleSettings?: OracleSettings;
  SybaseSettings?: SybaseSettings;
  MicrosoftSQLServerSettings?: MicrosoftSQLServerSettings;
  IBMDb2Settings?: IBMDb2Settings;
  DocDbSettings?: DocDbSettings;
  RedisSettings?: RedisSettings;
  GcpMySQLSettings?: GcpMySQLSettings;
  TimestreamSettings?: TimestreamSettings;
}
export interface CreateEndpointResponse {
  Endpoint?: Endpoint;
}
export declare class KMSKeyNotAccessibleFault extends __BaseException {
  readonly name: "KMSKeyNotAccessibleFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<KMSKeyNotAccessibleFault, __BaseException>
  );
}
export declare class S3AccessDeniedFault extends __BaseException {
  readonly name: "S3AccessDeniedFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<S3AccessDeniedFault, __BaseException>
  );
}
export interface CreateEventSubscriptionMessage {
  SubscriptionName: string | undefined;
  SnsTopicArn: string | undefined;
  SourceType?: string;
  EventCategories?: string[];
  SourceIds?: string[];
  Enabled?: boolean;
  Tags?: Tag[];
}
export interface EventSubscription {
  CustomerAwsId?: string;
  CustSubscriptionId?: string;
  SnsTopicArn?: string;
  Status?: string;
  SubscriptionCreationTime?: string;
  SourceType?: string;
  SourceIdsList?: string[];
  EventCategoriesList?: string[];
  Enabled?: boolean;
}
export interface CreateEventSubscriptionResponse {
  EventSubscription?: EventSubscription;
}
export declare class KMSAccessDeniedFault extends __BaseException {
  readonly name: "KMSAccessDeniedFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<KMSAccessDeniedFault, __BaseException>
  );
}
export declare class KMSDisabledFault extends __BaseException {
  readonly name: "KMSDisabledFault";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<KMSDisabledFault, __BaseException>);
}
export declare class KMSInvalidStateFault extends __BaseException {
  readonly name: "KMSInvalidStateFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<KMSInvalidStateFault, __BaseException>
  );
}
export declare class KMSNotFoundFault extends __BaseException {
  readonly name: "KMSNotFoundFault";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<KMSNotFoundFault, __BaseException>);
}
export declare class KMSThrottlingFault extends __BaseException {
  readonly name: "KMSThrottlingFault";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<KMSThrottlingFault, __BaseException>);
}
export declare class SNSInvalidTopicFault extends __BaseException {
  readonly name: "SNSInvalidTopicFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<SNSInvalidTopicFault, __BaseException>
  );
}
export declare class SNSNoAuthorizationFault extends __BaseException {
  readonly name: "SNSNoAuthorizationFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<SNSNoAuthorizationFault, __BaseException>
  );
}
export interface CreateFleetAdvisorCollectorRequest {
  CollectorName: string | undefined;
  Description?: string;
  ServiceAccessRoleArn: string | undefined;
  S3BucketName: string | undefined;
}
export interface CreateFleetAdvisorCollectorResponse {
  CollectorReferencedId?: string;
  CollectorName?: string;
  Description?: string;
  ServiceAccessRoleArn?: string;
  S3BucketName?: string;
}
export declare class S3ResourceNotFoundFault extends __BaseException {
  readonly name: "S3ResourceNotFoundFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<S3ResourceNotFoundFault, __BaseException>
  );
}
export interface CreateInstanceProfileMessage {
  AvailabilityZone?: string;
  KmsKeyArn?: string;
  PubliclyAccessible?: boolean;
  Tags?: Tag[];
  NetworkType?: string;
  InstanceProfileName?: string;
  Description?: string;
  SubnetGroupIdentifier?: string;
  VpcSecurityGroups?: string[];
}
export interface InstanceProfile {
  InstanceProfileArn?: string;
  AvailabilityZone?: string;
  KmsKeyArn?: string;
  PubliclyAccessible?: boolean;
  NetworkType?: string;
  InstanceProfileName?: string;
  Description?: string;
  InstanceProfileCreationTime?: Date;
  SubnetGroupIdentifier?: string;
  VpcSecurityGroups?: string[];
}
export interface CreateInstanceProfileResponse {
  InstanceProfile?: InstanceProfile;
}
export interface SCApplicationAttributes {
  S3BucketPath?: string;
  S3BucketRoleArn?: string;
}
export interface DataProviderDescriptorDefinition {
  DataProviderIdentifier: string | undefined;
  SecretsManagerSecretId?: string;
  SecretsManagerAccessRoleArn?: string;
}
export interface CreateMigrationProjectMessage {
  MigrationProjectName?: string;
  SourceDataProviderDescriptors: DataProviderDescriptorDefinition[] | undefined;
  TargetDataProviderDescriptors: DataProviderDescriptorDefinition[] | undefined;
  InstanceProfileIdentifier: string | undefined;
  TransformationRules?: string;
  Description?: string;
  Tags?: Tag[];
  SchemaConversionApplicationAttributes?: SCApplicationAttributes;
}
export interface DataProviderDescriptor {
  SecretsManagerSecretId?: string;
  SecretsManagerAccessRoleArn?: string;
  DataProviderName?: string;
  DataProviderArn?: string;
}
export interface MigrationProject {
  MigrationProjectName?: string;
  MigrationProjectArn?: string;
  MigrationProjectCreationTime?: Date;
  SourceDataProviderDescriptors?: DataProviderDescriptor[];
  TargetDataProviderDescriptors?: DataProviderDescriptor[];
  InstanceProfileArn?: string;
  InstanceProfileName?: string;
  TransformationRules?: string;
  Description?: string;
  SchemaConversionApplicationAttributes?: SCApplicationAttributes;
}
export interface CreateMigrationProjectResponse {
  MigrationProject?: MigrationProject;
}
export interface ComputeConfig {
  AvailabilityZone?: string;
  DnsNameServers?: string;
  KmsKeyId?: string;
  MaxCapacityUnits?: number;
  MinCapacityUnits?: number;
  MultiAZ?: boolean;
  PreferredMaintenanceWindow?: string;
  ReplicationSubnetGroupId?: string;
  VpcSecurityGroupIds?: string[];
}
export declare const MigrationTypeValue: {
  readonly CDC: "cdc";
  readonly FULL_LOAD: "full-load";
  readonly FULL_LOAD_AND_CDC: "full-load-and-cdc";
};
export type MigrationTypeValue =
  (typeof MigrationTypeValue)[keyof typeof MigrationTypeValue];
export interface CreateReplicationConfigMessage {
  ReplicationConfigIdentifier: string | undefined;
  SourceEndpointArn: string | undefined;
  TargetEndpointArn: string | undefined;
  ComputeConfig: ComputeConfig | undefined;
  ReplicationType: MigrationTypeValue | undefined;
  TableMappings: string | undefined;
  ReplicationSettings?: string;
  SupplementalSettings?: string;
  ResourceIdentifier?: string;
  Tags?: Tag[];
}
export interface ReplicationConfig {
  ReplicationConfigIdentifier?: string;
  ReplicationConfigArn?: string;
  SourceEndpointArn?: string;
  TargetEndpointArn?: string;
  ReplicationType?: MigrationTypeValue;
  ComputeConfig?: ComputeConfig;
  ReplicationSettings?: string;
  SupplementalSettings?: string;
  TableMappings?: string;
  ReplicationConfigCreateTime?: Date;
  ReplicationConfigUpdateTime?: Date;
}
export interface CreateReplicationConfigResponse {
  ReplicationConfig?: ReplicationConfig;
}
export declare class InvalidSubnet extends __BaseException {
  readonly name: "InvalidSubnet";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<InvalidSubnet, __BaseException>);
}
export declare class ReplicationSubnetGroupDoesNotCoverEnoughAZs extends __BaseException {
  readonly name: "ReplicationSubnetGroupDoesNotCoverEnoughAZs";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      ReplicationSubnetGroupDoesNotCoverEnoughAZs,
      __BaseException
    >
  );
}
export interface CreateReplicationInstanceMessage {
  ReplicationInstanceIdentifier: string | undefined;
  AllocatedStorage?: number;
  ReplicationInstanceClass: string | undefined;
  VpcSecurityGroupIds?: string[];
  AvailabilityZone?: string;
  ReplicationSubnetGroupIdentifier?: string;
  PreferredMaintenanceWindow?: string;
  MultiAZ?: boolean;
  EngineVersion?: string;
  AutoMinorVersionUpgrade?: boolean;
  Tags?: Tag[];
  KmsKeyId?: string;
  PubliclyAccessible?: boolean;
  DnsNameServers?: string;
  ResourceIdentifier?: string;
  NetworkType?: string;
}
export interface ReplicationPendingModifiedValues {
  ReplicationInstanceClass?: string;
  AllocatedStorage?: number;
  MultiAZ?: boolean;
  EngineVersion?: string;
  NetworkType?: string;
}
export interface AvailabilityZone {
  Name?: string;
}
export interface Subnet {
  SubnetIdentifier?: string;
  SubnetAvailabilityZone?: AvailabilityZone;
  SubnetStatus?: string;
}
export interface ReplicationSubnetGroup {
  ReplicationSubnetGroupIdentifier?: string;
  ReplicationSubnetGroupDescription?: string;
  VpcId?: string;
  SubnetGroupStatus?: string;
  Subnets?: Subnet[];
  SupportedNetworkTypes?: string[];
}
export interface VpcSecurityGroupMembership {
  VpcSecurityGroupId?: string;
  Status?: string;
}
export interface ReplicationInstance {
  ReplicationInstanceIdentifier?: string;
  ReplicationInstanceClass?: string;
  ReplicationInstanceStatus?: string;
  AllocatedStorage?: number;
  InstanceCreateTime?: Date;
  VpcSecurityGroups?: VpcSecurityGroupMembership[];
  AvailabilityZone?: string;
  ReplicationSubnetGroup?: ReplicationSubnetGroup;
  PreferredMaintenanceWindow?: string;
  PendingModifiedValues?: ReplicationPendingModifiedValues;
  MultiAZ?: boolean;
  EngineVersion?: string;
  AutoMinorVersionUpgrade?: boolean;
  KmsKeyId?: string;
  ReplicationInstanceArn?: string;
  ReplicationInstancePublicIpAddress?: string;
  ReplicationInstancePrivateIpAddress?: string;
  ReplicationInstancePublicIpAddresses?: string[];
  ReplicationInstancePrivateIpAddresses?: string[];
  ReplicationInstanceIpv6Addresses?: string[];
  PubliclyAccessible?: boolean;
  SecondaryAvailabilityZone?: string;
  FreeUntil?: Date;
  DnsNameServers?: string;
  NetworkType?: string;
}
export interface CreateReplicationInstanceResponse {
  ReplicationInstance?: ReplicationInstance;
}
export declare class InsufficientResourceCapacityFault extends __BaseException {
  readonly name: "InsufficientResourceCapacityFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      InsufficientResourceCapacityFault,
      __BaseException
    >
  );
}
export declare class StorageQuotaExceededFault extends __BaseException {
  readonly name: "StorageQuotaExceededFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<StorageQuotaExceededFault, __BaseException>
  );
}
export interface CreateReplicationSubnetGroupMessage {
  ReplicationSubnetGroupIdentifier: string | undefined;
  ReplicationSubnetGroupDescription: string | undefined;
  SubnetIds: string[] | undefined;
  Tags?: Tag[];
}
export interface CreateReplicationSubnetGroupResponse {
  ReplicationSubnetGroup?: ReplicationSubnetGroup;
}
export interface CreateReplicationTaskMessage {
  ReplicationTaskIdentifier: string | undefined;
  SourceEndpointArn: string | undefined;
  TargetEndpointArn: string | undefined;
  ReplicationInstanceArn: string | undefined;
  MigrationType: MigrationTypeValue | undefined;
  TableMappings: string | undefined;
  ReplicationTaskSettings?: string;
  CdcStartTime?: Date;
  CdcStartPosition?: string;
  CdcStopPosition?: string;
  Tags?: Tag[];
  TaskData?: string;
  ResourceIdentifier?: string;
}
export interface ReplicationTaskStats {
  FullLoadProgressPercent?: number;
  ElapsedTimeMillis?: number;
  TablesLoaded?: number;
  TablesLoading?: number;
  TablesQueued?: number;
  TablesErrored?: number;
  FreshStartDate?: Date;
  StartDate?: Date;
  StopDate?: Date;
  FullLoadStartDate?: Date;
  FullLoadFinishDate?: Date;
}
export interface ReplicationTask {
  ReplicationTaskIdentifier?: string;
  SourceEndpointArn?: string;
  TargetEndpointArn?: string;
  ReplicationInstanceArn?: string;
  MigrationType?: MigrationTypeValue;
  TableMappings?: string;
  ReplicationTaskSettings?: string;
  Status?: string;
  LastFailureMessage?: string;
  StopReason?: string;
  ReplicationTaskCreationDate?: Date;
  ReplicationTaskStartDate?: Date;
  CdcStartPosition?: string;
  CdcStopPosition?: string;
  RecoveryCheckpoint?: string;
  ReplicationTaskArn?: string;
  ReplicationTaskStats?: ReplicationTaskStats;
  TaskData?: string;
  TargetReplicationInstanceArn?: string;
}
export interface CreateReplicationTaskResponse {
  ReplicationTask?: ReplicationTask;
}
export interface DeleteCertificateMessage {
  CertificateArn: string | undefined;
}
export interface Certificate {
  CertificateIdentifier?: string;
  CertificateCreationDate?: Date;
  CertificatePem?: string;
  CertificateWallet?: Uint8Array;
  CertificateArn?: string;
  CertificateOwner?: string;
  ValidFromDate?: Date;
  ValidToDate?: Date;
  SigningAlgorithm?: string;
  KeyLength?: number;
}
export interface DeleteCertificateResponse {
  Certificate?: Certificate;
}
export interface DeleteConnectionMessage {
  EndpointArn: string | undefined;
  ReplicationInstanceArn: string | undefined;
}
export interface Connection {
  ReplicationInstanceArn?: string;
  EndpointArn?: string;
  Status?: string;
  LastFailureMessage?: string;
  EndpointIdentifier?: string;
  ReplicationInstanceIdentifier?: string;
}
export interface DeleteConnectionResponse {
  Connection?: Connection;
}
export interface DeleteDataProviderMessage {
  DataProviderIdentifier: string | undefined;
}
export interface DeleteDataProviderResponse {
  DataProvider?: DataProvider;
}
export interface DeleteEndpointMessage {
  EndpointArn: string | undefined;
}
export interface DeleteEndpointResponse {
  Endpoint?: Endpoint;
}
export interface DeleteEventSubscriptionMessage {
  SubscriptionName: string | undefined;
}
export interface DeleteEventSubscriptionResponse {
  EventSubscription?: EventSubscription;
}
export declare class CollectorNotFoundFault extends __BaseException {
  readonly name: "CollectorNotFoundFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<CollectorNotFoundFault, __BaseException>
  );
}
export interface DeleteCollectorRequest {
  CollectorReferencedId: string | undefined;
}
export interface DeleteFleetAdvisorDatabasesRequest {
  DatabaseIds: string[] | undefined;
}
export interface DeleteFleetAdvisorDatabasesResponse {
  DatabaseIds?: string[];
}
export declare class InvalidOperationFault extends __BaseException {
  readonly name: "InvalidOperationFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidOperationFault, __BaseException>
  );
}
export interface DeleteInstanceProfileMessage {
  InstanceProfileIdentifier: string | undefined;
}
export interface DeleteInstanceProfileResponse {
  InstanceProfile?: InstanceProfile;
}
export interface DeleteMigrationProjectMessage {
  MigrationProjectIdentifier: string | undefined;
}
export interface DeleteMigrationProjectResponse {
  MigrationProject?: MigrationProject;
}
export interface DeleteReplicationConfigMessage {
  ReplicationConfigArn: string | undefined;
}
export interface DeleteReplicationConfigResponse {
  ReplicationConfig?: ReplicationConfig;
}
export interface DeleteReplicationInstanceMessage {
  ReplicationInstanceArn: string | undefined;
}
export interface DeleteReplicationInstanceResponse {
  ReplicationInstance?: ReplicationInstance;
}
export interface DeleteReplicationSubnetGroupMessage {
  ReplicationSubnetGroupIdentifier: string | undefined;
}
export interface DeleteReplicationSubnetGroupResponse {}
export interface DeleteReplicationTaskMessage {
  ReplicationTaskArn: string | undefined;
}
export interface DeleteReplicationTaskResponse {
  ReplicationTask?: ReplicationTask;
}
export interface DeleteReplicationTaskAssessmentRunMessage {
  ReplicationTaskAssessmentRunArn: string | undefined;
}
export interface DeleteReplicationTaskAssessmentRunResponse {
  ReplicationTaskAssessmentRun?: ReplicationTaskAssessmentRun;
}
export interface DescribeAccountAttributesMessage {}
export interface DescribeAccountAttributesResponse {
  AccountQuotas?: AccountQuota[];
  UniqueAccountIdentifier?: string;
}
export interface DescribeApplicableIndividualAssessmentsMessage {
  ReplicationTaskArn?: string;
  ReplicationInstanceArn?: string;
  SourceEngineName?: string;
  TargetEngineName?: string;
  MigrationType?: MigrationTypeValue;
  MaxRecords?: number;
  Marker?: string;
}
export interface DescribeApplicableIndividualAssessmentsResponse {
  IndividualAssessmentNames?: string[];
  Marker?: string;
}
export interface Filter {
  Name: string | undefined;
  Values: string[] | undefined;
}
export interface DescribeCertificatesMessage {
  Filters?: Filter[];
  MaxRecords?: number;
  Marker?: string;
}
export interface DescribeCertificatesResponse {
  Marker?: string;
  Certificates?: Certificate[];
}
export interface DescribeConnectionsMessage {
  Filters?: Filter[];
  MaxRecords?: number;
  Marker?: string;
}
export interface DescribeConnectionsResponse {
  Marker?: string;
  Connections?: Connection[];
}
export interface DescribeConversionConfigurationMessage {
  MigrationProjectIdentifier: string | undefined;
}
export interface DescribeConversionConfigurationResponse {
  MigrationProjectIdentifier?: string;
  ConversionConfiguration?: string;
}
export interface DescribeDataProvidersMessage {
  Filters?: Filter[];
  MaxRecords?: number;
  Marker?: string;
}
export interface DescribeDataProvidersResponse {
  Marker?: string;
  DataProviders?: DataProvider[];
}
export interface DescribeEndpointsMessage {
  Filters?: Filter[];
  MaxRecords?: number;
  Marker?: string;
}
export interface DescribeEndpointsResponse {
  Marker?: string;
  Endpoints?: Endpoint[];
}
export interface DescribeEndpointSettingsMessage {
  EngineName: string | undefined;
  MaxRecords?: number;
  Marker?: string;
}
export declare const EndpointSettingTypeValue: {
  readonly BOOLEAN: "boolean";
  readonly ENUM: "enum";
  readonly INTEGER: "integer";
  readonly STRING: "string";
};
export type EndpointSettingTypeValue =
  (typeof EndpointSettingTypeValue)[keyof typeof EndpointSettingTypeValue];
export interface EndpointSetting {
  Name?: string;
  Type?: EndpointSettingTypeValue;
  EnumValues?: string[];
  Sensitive?: boolean;
  Units?: string;
  Applicability?: string;
  IntValueMin?: number;
  IntValueMax?: number;
  DefaultValue?: string;
}
export interface DescribeEndpointSettingsResponse {
  Marker?: string;
  EndpointSettings?: EndpointSetting[];
}
export interface DescribeEndpointTypesMessage {
  Filters?: Filter[];
  MaxRecords?: number;
  Marker?: string;
}
export interface SupportedEndpointType {
  EngineName?: string;
  SupportsCDC?: boolean;
  EndpointType?: ReplicationEndpointTypeValue;
  ReplicationInstanceEngineMinimumVersion?: string;
  EngineDisplayName?: string;
}
export interface DescribeEndpointTypesResponse {
  Marker?: string;
  SupportedEndpointTypes?: SupportedEndpointType[];
}
export interface DescribeEngineVersionsMessage {
  MaxRecords?: number;
  Marker?: string;
}
export declare const ReleaseStatusValues: {
  readonly BETA: "beta";
  readonly PROD: "prod";
};
export type ReleaseStatusValues =
  (typeof ReleaseStatusValues)[keyof typeof ReleaseStatusValues];
export interface EngineVersion {
  Version?: string;
  Lifecycle?: string;
  ReleaseStatus?: ReleaseStatusValues;
  LaunchDate?: Date;
  AutoUpgradeDate?: Date;
  DeprecationDate?: Date;
  ForceUpgradeDate?: Date;
  AvailableUpgrades?: string[];
}
export interface DescribeEngineVersionsResponse {
  EngineVersions?: EngineVersion[];
  Marker?: string;
}
export interface DescribeEventCategoriesMessage {
  SourceType?: string;
  Filters?: Filter[];
}
export interface EventCategoryGroup {
  SourceType?: string;
  EventCategories?: string[];
}
export interface DescribeEventCategoriesResponse {
  EventCategoryGroupList?: EventCategoryGroup[];
}
export declare const SourceType: {
  readonly replication_instance: "replication-instance";
};
export type SourceType = (typeof SourceType)[keyof typeof SourceType];
export interface DescribeEventsMessage {
  SourceIdentifier?: string;
  SourceType?: SourceType;
  StartTime?: Date;
  EndTime?: Date;
  Duration?: number;
  EventCategories?: string[];
  Filters?: Filter[];
  MaxRecords?: number;
  Marker?: string;
}
export interface Event {
  SourceIdentifier?: string;
  SourceType?: SourceType;
  Message?: string;
  EventCategories?: string[];
  Date?: Date;
}
export interface DescribeEventsResponse {
  Marker?: string;
  Events?: Event[];
}
export interface DescribeEventSubscriptionsMessage {
  SubscriptionName?: string;
  Filters?: Filter[];
  MaxRecords?: number;
  Marker?: string;
}
export interface DescribeEventSubscriptionsResponse {
  Marker?: string;
  EventSubscriptionsList?: EventSubscription[];
}
export interface DescribeExtensionPackAssociationsMessage {
  MigrationProjectIdentifier: string | undefined;
  Filters?: Filter[];
  Marker?: string;
  MaxRecords?: number;
}
export interface DefaultErrorDetails {
  Message?: string;
}
export type ErrorDetails =
  | ErrorDetails.DefaultErrorDetailsMember
  | ErrorDetails.$UnknownMember;
export declare namespace ErrorDetails {
  interface DefaultErrorDetailsMember {
    defaultErrorDetails: DefaultErrorDetails;
    $unknown?: never;
  }
  interface $UnknownMember {
    defaultErrorDetails?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    defaultErrorDetails: (value: DefaultErrorDetails) => T;
    _: (name: string, value: any) => T;
  }
  const visit: <T>(value: ErrorDetails, visitor: Visitor<T>) => T;
}
export interface ExportSqlDetails {
  S3ObjectKey?: string;
  ObjectURL?: string;
}
export interface SchemaConversionRequest {
  Status?: string;
  RequestIdentifier?: string;
  MigrationProjectArn?: string;
  Error?: ErrorDetails;
  ExportSqlDetails?: ExportSqlDetails;
}
export interface DescribeExtensionPackAssociationsResponse {
  Marker?: string;
  Requests?: SchemaConversionRequest[];
}
export interface DescribeFleetAdvisorCollectorsRequest {
  Filters?: Filter[];
  MaxRecords?: number;
  NextToken?: string;
}
export declare const CollectorStatus: {
  readonly ACTIVE: "ACTIVE";
  readonly UNREGISTERED: "UNREGISTERED";
};
export type CollectorStatus =
  (typeof CollectorStatus)[keyof typeof CollectorStatus];
export interface CollectorHealthCheck {
  CollectorStatus?: CollectorStatus;
  LocalCollectorS3Access?: boolean;
  WebCollectorS3Access?: boolean;
  WebCollectorGrantedRoleBasedAccess?: boolean;
}
export interface InventoryData {
  NumberOfDatabases?: number;
  NumberOfSchemas?: number;
}
export declare const VersionStatus: {
  readonly OUTDATED: "OUTDATED";
  readonly UNSUPPORTED: "UNSUPPORTED";
  readonly UP_TO_DATE: "UP_TO_DATE";
};
export type VersionStatus = (typeof VersionStatus)[keyof typeof VersionStatus];
export interface CollectorResponse {
  CollectorReferencedId?: string;
  CollectorName?: string;
  CollectorVersion?: string;
  VersionStatus?: VersionStatus;
  Description?: string;
  S3BucketName?: string;
  ServiceAccessRoleArn?: string;
  CollectorHealthCheck?: CollectorHealthCheck;
  LastDataReceived?: string;
  RegisteredDate?: string;
  CreatedDate?: string;
  ModifiedDate?: string;
  InventoryData?: InventoryData;
}
export interface DescribeFleetAdvisorCollectorsResponse {
  Collectors?: CollectorResponse[];
  NextToken?: string;
}
export interface DescribeFleetAdvisorDatabasesRequest {
  Filters?: Filter[];
  MaxRecords?: number;
  NextToken?: string;
}
export interface CollectorShortInfoResponse {
  CollectorReferencedId?: string;
  CollectorName?: string;
}
export interface ServerShortInfoResponse {
  ServerId?: string;
  IpAddress?: string;
  ServerName?: string;
}
export interface DatabaseInstanceSoftwareDetailsResponse {
  Engine?: string;
  EngineVersion?: string;
  EngineEdition?: string;
  ServicePack?: string;
  SupportLevel?: string;
  OsArchitecture?: number;
  Tooltip?: string;
}
export interface DatabaseResponse {
  DatabaseId?: string;
  DatabaseName?: string;
  IpAddress?: string;
  NumberOfSchemas?: number;
  Server?: ServerShortInfoResponse;
  SoftwareDetails?: DatabaseInstanceSoftwareDetailsResponse;
  Collectors?: CollectorShortInfoResponse[];
}
export interface DescribeFleetAdvisorDatabasesResponse {
  Databases?: DatabaseResponse[];
  NextToken?: string;
}
export interface DescribeFleetAdvisorLsaAnalysisRequest {
  MaxRecords?: number;
  NextToken?: string;
}
export interface FleetAdvisorLsaAnalysisResponse {
  LsaAnalysisId?: string;
  Status?: string;
}
export interface DescribeFleetAdvisorLsaAnalysisResponse {
  Analysis?: FleetAdvisorLsaAnalysisResponse[];
  NextToken?: string;
}
export interface DescribeFleetAdvisorSchemaObjectSummaryRequest {
  Filters?: Filter[];
  MaxRecords?: number;
  NextToken?: string;
}
export interface FleetAdvisorSchemaObjectResponse {
  SchemaId?: string;
  ObjectType?: string;
  NumberOfObjects?: number;
  CodeLineCount?: number;
  CodeSize?: number;
}
export interface DescribeFleetAdvisorSchemaObjectSummaryResponse {
  FleetAdvisorSchemaObjects?: FleetAdvisorSchemaObjectResponse[];
  NextToken?: string;
}
export interface DescribeFleetAdvisorSchemasRequest {
  Filters?: Filter[];
  MaxRecords?: number;
  NextToken?: string;
}
export interface DatabaseShortInfoResponse {
  DatabaseId?: string;
  DatabaseName?: string;
  DatabaseIpAddress?: string;
  DatabaseEngine?: string;
}
export interface SchemaShortInfoResponse {
  SchemaId?: string;
  SchemaName?: string;
  DatabaseId?: string;
  DatabaseName?: string;
  DatabaseIpAddress?: string;
}
export interface SchemaResponse {
  CodeLineCount?: number;
  CodeSize?: number;
  Complexity?: string;
  Server?: ServerShortInfoResponse;
  DatabaseInstance?: DatabaseShortInfoResponse;
  SchemaId?: string;
  SchemaName?: string;
  OriginalSchema?: SchemaShortInfoResponse;
  Similarity?: number;
}
export interface DescribeFleetAdvisorSchemasResponse {
  FleetAdvisorSchemas?: SchemaResponse[];
  NextToken?: string;
}
export interface DescribeInstanceProfilesMessage {
  Filters?: Filter[];
  MaxRecords?: number;
  Marker?: string;
}
export interface DescribeInstanceProfilesResponse {
  Marker?: string;
  InstanceProfiles?: InstanceProfile[];
}
export interface DescribeMetadataModelAssessmentsMessage {
  MigrationProjectIdentifier: string | undefined;
  Filters?: Filter[];
  Marker?: string;
  MaxRecords?: number;
}
export interface DescribeMetadataModelAssessmentsResponse {
  Marker?: string;
  Requests?: SchemaConversionRequest[];
}
export interface DescribeMetadataModelConversionsMessage {
  MigrationProjectIdentifier: string | undefined;
  Filters?: Filter[];
  Marker?: string;
  MaxRecords?: number;
}
export interface DescribeMetadataModelConversionsResponse {
  Marker?: string;
  Requests?: SchemaConversionRequest[];
}
export interface DescribeMetadataModelExportsAsScriptMessage {
  MigrationProjectIdentifier: string | undefined;
  Filters?: Filter[];
  Marker?: string;
  MaxRecords?: number;
}
export interface DescribeMetadataModelExportsAsScriptResponse {
  Marker?: string;
  Requests?: SchemaConversionRequest[];
}
export interface DescribeMetadataModelExportsToTargetMessage {
  MigrationProjectIdentifier: string | undefined;
  Filters?: Filter[];
  Marker?: string;
  MaxRecords?: number;
}
export interface DescribeMetadataModelExportsToTargetResponse {
  Marker?: string;
  Requests?: SchemaConversionRequest[];
}
export interface DescribeMetadataModelImportsMessage {
  MigrationProjectIdentifier: string | undefined;
  Filters?: Filter[];
  Marker?: string;
  MaxRecords?: number;
}
export interface DescribeMetadataModelImportsResponse {
  Marker?: string;
  Requests?: SchemaConversionRequest[];
}
export interface DescribeMigrationProjectsMessage {
  Filters?: Filter[];
  MaxRecords?: number;
  Marker?: string;
}
export interface DescribeMigrationProjectsResponse {
  Marker?: string;
  MigrationProjects?: MigrationProject[];
}
export interface DescribeOrderableReplicationInstancesMessage {
  MaxRecords?: number;
  Marker?: string;
}
export interface OrderableReplicationInstance {
  EngineVersion?: string;
  ReplicationInstanceClass?: string;
  StorageType?: string;
  MinAllocatedStorage?: number;
  MaxAllocatedStorage?: number;
  DefaultAllocatedStorage?: number;
  IncludedAllocatedStorage?: number;
  AvailabilityZones?: string[];
  ReleaseStatus?: ReleaseStatusValues;
}
export interface DescribeOrderableReplicationInstancesResponse {
  OrderableReplicationInstances?: OrderableReplicationInstance[];
  Marker?: string;
}
export interface DescribePendingMaintenanceActionsMessage {
  ReplicationInstanceArn?: string;
  Filters?: Filter[];
  Marker?: string;
  MaxRecords?: number;
}
export interface DescribePendingMaintenanceActionsResponse {
  PendingMaintenanceActions?: ResourcePendingMaintenanceActions[];
  Marker?: string;
}
export interface DescribeRecommendationLimitationsRequest {
  Filters?: Filter[];
  MaxRecords?: number;
  NextToken?: string;
}
export interface Limitation {
  DatabaseId?: string;
  EngineName?: string;
  Name?: string;
  Description?: string;
  Impact?: string;
  Type?: string;
}
export interface DescribeRecommendationLimitationsResponse {
  NextToken?: string;
  Limitations?: Limitation[];
}
export interface DescribeRecommendationsRequest {
  Filters?: Filter[];
  MaxRecords?: number;
  NextToken?: string;
}
export interface RdsRequirements {
  EngineEdition?: string;
  InstanceVcpu?: number;
  InstanceMemory?: number;
  StorageSize?: number;
  StorageIops?: number;
  DeploymentOption?: string;
  EngineVersion?: string;
}
export interface RdsConfiguration {
  EngineEdition?: string;
  InstanceType?: string;
  InstanceVcpu?: number;
  InstanceMemory?: number;
  StorageType?: string;
  StorageSize?: number;
  StorageIops?: number;
  DeploymentOption?: string;
  EngineVersion?: string;
}
export interface RdsRecommendation {
  RequirementsToTarget?: RdsRequirements;
  TargetConfiguration?: RdsConfiguration;
}
export interface RecommendationData {
  RdsEngine?: RdsRecommendation;
}
export interface Recommendation {
  DatabaseId?: string;
  EngineName?: string;
  CreatedDate?: string;
  Status?: string;
  Preferred?: boolean;
  Settings?: RecommendationSettings;
  Data?: RecommendationData;
}
export interface DescribeRecommendationsResponse {
  NextToken?: string;
  Recommendations?: Recommendation[];
}
export interface DescribeRefreshSchemasStatusMessage {
  EndpointArn: string | undefined;
}
export declare const RefreshSchemasStatusTypeValue: {
  readonly FAILED: "failed";
  readonly REFRESHING: "refreshing";
  readonly SUCCESSFUL: "successful";
};
export type RefreshSchemasStatusTypeValue =
  (typeof RefreshSchemasStatusTypeValue)[keyof typeof RefreshSchemasStatusTypeValue];
export interface RefreshSchemasStatus {
  EndpointArn?: string;
  ReplicationInstanceArn?: string;
  Status?: RefreshSchemasStatusTypeValue;
  LastRefreshDate?: Date;
  LastFailureMessage?: string;
}
export interface DescribeRefreshSchemasStatusResponse {
  RefreshSchemasStatus?: RefreshSchemasStatus;
}
export interface DescribeReplicationConfigsMessage {
  Filters?: Filter[];
  MaxRecords?: number;
  Marker?: string;
}
export interface DescribeReplicationConfigsResponse {
  Marker?: string;
  ReplicationConfigs?: ReplicationConfig[];
}
export interface DescribeReplicationInstancesMessage {
  Filters?: Filter[];
  MaxRecords?: number;
  Marker?: string;
}
export interface DescribeReplicationInstancesResponse {
  Marker?: string;
  ReplicationInstances?: ReplicationInstance[];
}
export interface DescribeReplicationInstanceTaskLogsMessage {
  ReplicationInstanceArn: string | undefined;
  MaxRecords?: number;
  Marker?: string;
}
export interface ReplicationInstanceTaskLog {
  ReplicationTaskName?: string;
  ReplicationTaskArn?: string;
  ReplicationInstanceTaskLogSize?: number;
}
export interface DescribeReplicationInstanceTaskLogsResponse {
  ReplicationInstanceArn?: string;
  ReplicationInstanceTaskLogs?: ReplicationInstanceTaskLog[];
  Marker?: string;
}
export interface DescribeReplicationsMessage {
  Filters?: Filter[];
  MaxRecords?: number;
  Marker?: string;
}
export interface ProvisionData {
  ProvisionState?: string;
  ProvisionedCapacityUnits?: number;
  DateProvisioned?: Date;
  IsNewProvisioningAvailable?: boolean;
  DateNewProvisioningDataAvailable?: Date;
  ReasonForNewProvisioningData?: string;
}
export interface ReplicationStats {
  FullLoadProgressPercent?: number;
  ElapsedTimeMillis?: number;
  TablesLoaded?: number;
  TablesLoading?: number;
  TablesQueued?: number;
  TablesErrored?: number;
  FreshStartDate?: Date;
  StartDate?: Date;
  StopDate?: Date;
  FullLoadStartDate?: Date;
  FullLoadFinishDate?: Date;
}
export interface Replication {
  ReplicationConfigIdentifier?: string;
  ReplicationConfigArn?: string;
  SourceEndpointArn?: string;
  TargetEndpointArn?: string;
  ReplicationType?: MigrationTypeValue;
  Status?: string;
  ProvisionData?: ProvisionData;
  StopReason?: string;
  FailureMessages?: string[];
  ReplicationStats?: ReplicationStats;
  StartReplicationType?: string;
  CdcStartTime?: Date;
  CdcStartPosition?: string;
  CdcStopPosition?: string;
  RecoveryCheckpoint?: string;
  ReplicationCreateTime?: Date;
  ReplicationUpdateTime?: Date;
  ReplicationLastStopTime?: Date;
  ReplicationDeprovisionTime?: Date;
}
export interface DescribeReplicationsResponse {
  Marker?: string;
  Replications?: Replication[];
}
export interface DescribeReplicationSubnetGroupsMessage {
  Filters?: Filter[];
  MaxRecords?: number;
  Marker?: string;
}
export interface DescribeReplicationSubnetGroupsResponse {
  Marker?: string;
  ReplicationSubnetGroups?: ReplicationSubnetGroup[];
}
export interface DescribeReplicationTableStatisticsMessage {
  ReplicationConfigArn: string | undefined;
  MaxRecords?: number;
  Marker?: string;
  Filters?: Filter[];
}
export interface TableStatistics {
  SchemaName?: string;
  TableName?: string;
  Inserts?: number;
  Deletes?: number;
  Updates?: number;
  Ddls?: number;
  AppliedInserts?: number;
  AppliedDeletes?: number;
  AppliedUpdates?: number;
  AppliedDdls?: number;
  FullLoadRows?: number;
  FullLoadCondtnlChkFailedRows?: number;
  FullLoadErrorRows?: number;
  FullLoadStartTime?: Date;
  FullLoadEndTime?: Date;
  FullLoadReloaded?: boolean;
  LastUpdateTime?: Date;
  TableState?: string;
  ValidationPendingRecords?: number;
  ValidationFailedRecords?: number;
  ValidationSuspendedRecords?: number;
  ValidationState?: string;
  ValidationStateDetails?: string;
}
export interface DescribeReplicationTableStatisticsResponse {
  ReplicationConfigArn?: string;
  Marker?: string;
  ReplicationTableStatistics?: TableStatistics[];
}
export interface DescribeReplicationTaskAssessmentResultsMessage {
  ReplicationTaskArn?: string;
  MaxRecords?: number;
  Marker?: string;
}
export interface ReplicationTaskAssessmentResult {
  ReplicationTaskIdentifier?: string;
  ReplicationTaskArn?: string;
  ReplicationTaskLastAssessmentDate?: Date;
  AssessmentStatus?: string;
  AssessmentResultsFile?: string;
  AssessmentResults?: string;
  S3ObjectUrl?: string;
}
export interface DescribeReplicationTaskAssessmentResultsResponse {
  Marker?: string;
  BucketName?: string;
  ReplicationTaskAssessmentResults?: ReplicationTaskAssessmentResult[];
}
export interface DescribeReplicationTaskAssessmentRunsMessage {
  Filters?: Filter[];
  MaxRecords?: number;
  Marker?: string;
}
export interface DescribeReplicationTaskAssessmentRunsResponse {
  Marker?: string;
  ReplicationTaskAssessmentRuns?: ReplicationTaskAssessmentRun[];
}
export interface DescribeReplicationTaskIndividualAssessmentsMessage {
  Filters?: Filter[];
  MaxRecords?: number;
  Marker?: string;
}
export interface ReplicationTaskIndividualAssessment {
  ReplicationTaskIndividualAssessmentArn?: string;
  ReplicationTaskAssessmentRunArn?: string;
  IndividualAssessmentName?: string;
  Status?: string;
  ReplicationTaskIndividualAssessmentStartDate?: Date;
}
export interface DescribeReplicationTaskIndividualAssessmentsResponse {
  Marker?: string;
  ReplicationTaskIndividualAssessments?: ReplicationTaskIndividualAssessment[];
}
export interface DescribeReplicationTasksMessage {
  Filters?: Filter[];
  MaxRecords?: number;
  Marker?: string;
  WithoutSettings?: boolean;
}
export interface DescribeReplicationTasksResponse {
  Marker?: string;
  ReplicationTasks?: ReplicationTask[];
}
export interface DescribeSchemasMessage {
  EndpointArn: string | undefined;
  MaxRecords?: number;
  Marker?: string;
}
export interface DescribeSchemasResponse {
  Marker?: string;
  Schemas?: string[];
}
export interface DescribeTableStatisticsMessage {
  ReplicationTaskArn: string | undefined;
  MaxRecords?: number;
  Marker?: string;
  Filters?: Filter[];
}
export interface DescribeTableStatisticsResponse {
  ReplicationTaskArn?: string;
  TableStatistics?: TableStatistics[];
  Marker?: string;
}
export declare const AssessmentReportType: {
  readonly CSV: "csv";
  readonly PDF: "pdf";
};
export type AssessmentReportType =
  (typeof AssessmentReportType)[keyof typeof AssessmentReportType];
export interface ExportMetadataModelAssessmentMessage {
  MigrationProjectIdentifier: string | undefined;
  SelectionRules: string | undefined;
  FileName?: string;
  AssessmentReportTypes?: AssessmentReportType[];
}
export interface ExportMetadataModelAssessmentResultEntry {
  S3ObjectKey?: string;
  ObjectURL?: string;
}
export interface ExportMetadataModelAssessmentResponse {
  PdfReport?: ExportMetadataModelAssessmentResultEntry;
  CsvReport?: ExportMetadataModelAssessmentResultEntry;
}
export interface ImportCertificateMessage {
  CertificateIdentifier: string | undefined;
  CertificatePem?: string;
  CertificateWallet?: Uint8Array;
  Tags?: Tag[];
}
export interface ImportCertificateResponse {
  Certificate?: Certificate;
}
export declare class InvalidCertificateFault extends __BaseException {
  readonly name: "InvalidCertificateFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidCertificateFault, __BaseException>
  );
}
export interface ListTagsForResourceMessage {
  ResourceArn?: string;
  ResourceArnList?: string[];
}
export interface ListTagsForResourceResponse {
  TagList?: Tag[];
}
export interface ModifyConversionConfigurationMessage {
  MigrationProjectIdentifier: string | undefined;
  ConversionConfiguration: string | undefined;
}
export interface ModifyConversionConfigurationResponse {
  MigrationProjectIdentifier?: string;
}
export declare const DocDbSettingsFilterSensitiveLog: (
  obj: DocDbSettings
) => any;
export declare const GcpMySQLSettingsFilterSensitiveLog: (
  obj: GcpMySQLSettings
) => any;
export declare const IBMDb2SettingsFilterSensitiveLog: (
  obj: IBMDb2Settings
) => any;
export declare const KafkaSettingsFilterSensitiveLog: (
  obj: KafkaSettings
) => any;
export declare const MicrosoftSQLServerSettingsFilterSensitiveLog: (
  obj: MicrosoftSQLServerSettings
) => any;
export declare const MongoDbSettingsFilterSensitiveLog: (
  obj: MongoDbSettings
) => any;
export declare const MySQLSettingsFilterSensitiveLog: (
  obj: MySQLSettings
) => any;
export declare const OracleSettingsFilterSensitiveLog: (
  obj: OracleSettings
) => any;
export declare const PostgreSQLSettingsFilterSensitiveLog: (
  obj: PostgreSQLSettings
) => any;
export declare const RedisSettingsFilterSensitiveLog: (
  obj: RedisSettings
) => any;
export declare const RedshiftSettingsFilterSensitiveLog: (
  obj: RedshiftSettings
) => any;
export declare const SybaseSettingsFilterSensitiveLog: (
  obj: SybaseSettings
) => any;
export declare const CreateEndpointMessageFilterSensitiveLog: (
  obj: CreateEndpointMessage
) => any;
export declare const EndpointFilterSensitiveLog: (obj: Endpoint) => any;
export declare const CreateEndpointResponseFilterSensitiveLog: (
  obj: CreateEndpointResponse
) => any;
export declare const DeleteEndpointResponseFilterSensitiveLog: (
  obj: DeleteEndpointResponse
) => any;
export declare const DescribeEndpointsResponseFilterSensitiveLog: (
  obj: DescribeEndpointsResponse
) => any;
export declare const ImportCertificateMessageFilterSensitiveLog: (
  obj: ImportCertificateMessage
) => any;
