import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { DatabaseMigrationServiceServiceException as __BaseException } from "./DatabaseMigrationServiceServiceException";
import {
  ComputeConfig,
  Connection,
  DataProvider,
  DataProviderDescriptorDefinition,
  DataProviderSettings,
  DmsSslModeValue,
  DmsTransferSettings,
  DocDbSettings,
  DynamoDbSettings,
  ElasticsearchSettings,
  Endpoint,
  EventSubscription,
  GcpMySQLSettings,
  IBMDb2Settings,
  InstanceProfile,
  KafkaSettings,
  KinesisSettings,
  MicrosoftSQLServerSettings,
  MigrationProject,
  MigrationTypeValue,
  MongoDbSettings,
  MySQLSettings,
  NeptuneSettings,
  OracleSettings,
  PostgreSQLSettings,
  RecommendationSettings,
  RedisSettings,
  RedshiftSettings,
  RefreshSchemasStatus,
  Replication,
  ReplicationConfig,
  ReplicationEndpointTypeValue,
  ReplicationInstance,
  ReplicationSubnetGroup,
  ReplicationTask,
  ReplicationTaskAssessmentRun,
  S3Settings,
  SCApplicationAttributes,
  SybaseSettings,
  TimestreamSettings,
} from "./models_0";
export interface ModifyDataProviderMessage {
  DataProviderIdentifier: string | undefined;
  DataProviderName?: string;
  Description?: string;
  Engine?: string;
  ExactSettings?: boolean;
  Settings?: DataProviderSettings;
}
export interface ModifyDataProviderResponse {
  DataProvider?: DataProvider;
}
export interface ModifyEndpointMessage {
  EndpointArn: string | undefined;
  EndpointIdentifier?: string;
  EndpointType?: ReplicationEndpointTypeValue;
  EngineName?: string;
  Username?: string;
  Password?: string;
  ServerName?: string;
  Port?: number;
  DatabaseName?: string;
  ExtraConnectionAttributes?: string;
  CertificateArn?: string;
  SslMode?: DmsSslModeValue;
  ServiceAccessRoleArn?: string;
  ExternalTableDefinition?: string;
  DynamoDbSettings?: DynamoDbSettings;
  S3Settings?: S3Settings;
  DmsTransferSettings?: DmsTransferSettings;
  MongoDbSettings?: MongoDbSettings;
  KinesisSettings?: KinesisSettings;
  KafkaSettings?: KafkaSettings;
  ElasticsearchSettings?: ElasticsearchSettings;
  NeptuneSettings?: NeptuneSettings;
  RedshiftSettings?: RedshiftSettings;
  PostgreSQLSettings?: PostgreSQLSettings;
  MySQLSettings?: MySQLSettings;
  OracleSettings?: OracleSettings;
  SybaseSettings?: SybaseSettings;
  MicrosoftSQLServerSettings?: MicrosoftSQLServerSettings;
  IBMDb2Settings?: IBMDb2Settings;
  DocDbSettings?: DocDbSettings;
  RedisSettings?: RedisSettings;
  ExactSettings?: boolean;
  GcpMySQLSettings?: GcpMySQLSettings;
  TimestreamSettings?: TimestreamSettings;
}
export interface ModifyEndpointResponse {
  Endpoint?: Endpoint;
}
export interface ModifyEventSubscriptionMessage {
  SubscriptionName: string | undefined;
  SnsTopicArn?: string;
  SourceType?: string;
  EventCategories?: string[];
  Enabled?: boolean;
}
export interface ModifyEventSubscriptionResponse {
  EventSubscription?: EventSubscription;
}
export interface ModifyInstanceProfileMessage {
  InstanceProfileIdentifier: string | undefined;
  AvailabilityZone?: string;
  KmsKeyArn?: string;
  PubliclyAccessible?: boolean;
  NetworkType?: string;
  InstanceProfileName?: string;
  Description?: string;
  SubnetGroupIdentifier?: string;
  VpcSecurityGroups?: string[];
}
export interface ModifyInstanceProfileResponse {
  InstanceProfile?: InstanceProfile;
}
export interface ModifyMigrationProjectMessage {
  MigrationProjectIdentifier: string | undefined;
  MigrationProjectName?: string;
  SourceDataProviderDescriptors?: DataProviderDescriptorDefinition[];
  TargetDataProviderDescriptors?: DataProviderDescriptorDefinition[];
  InstanceProfileIdentifier?: string;
  TransformationRules?: string;
  Description?: string;
  SchemaConversionApplicationAttributes?: SCApplicationAttributes;
}
export interface ModifyMigrationProjectResponse {
  MigrationProject?: MigrationProject;
}
export interface ModifyReplicationConfigMessage {
  ReplicationConfigArn: string | undefined;
  ReplicationConfigIdentifier?: string;
  ReplicationType?: MigrationTypeValue;
  TableMappings?: string;
  ReplicationSettings?: string;
  SupplementalSettings?: string;
  ComputeConfig?: ComputeConfig;
  SourceEndpointArn?: string;
  TargetEndpointArn?: string;
}
export interface ModifyReplicationConfigResponse {
  ReplicationConfig?: ReplicationConfig;
}
export interface ModifyReplicationInstanceMessage {
  ReplicationInstanceArn: string | undefined;
  AllocatedStorage?: number;
  ApplyImmediately?: boolean;
  ReplicationInstanceClass?: string;
  VpcSecurityGroupIds?: string[];
  PreferredMaintenanceWindow?: string;
  MultiAZ?: boolean;
  EngineVersion?: string;
  AllowMajorVersionUpgrade?: boolean;
  AutoMinorVersionUpgrade?: boolean;
  ReplicationInstanceIdentifier?: string;
  NetworkType?: string;
}
export interface ModifyReplicationInstanceResponse {
  ReplicationInstance?: ReplicationInstance;
}
export declare class UpgradeDependencyFailureFault extends __BaseException {
  readonly name: "UpgradeDependencyFailureFault";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<UpgradeDependencyFailureFault, __BaseException>
  );
}
export interface ModifyReplicationSubnetGroupMessage {
  ReplicationSubnetGroupIdentifier: string | undefined;
  ReplicationSubnetGroupDescription?: string;
  SubnetIds: string[] | undefined;
}
export interface ModifyReplicationSubnetGroupResponse {
  ReplicationSubnetGroup?: ReplicationSubnetGroup;
}
export declare class SubnetAlreadyInUse extends __BaseException {
  readonly name: "SubnetAlreadyInUse";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<SubnetAlreadyInUse, __BaseException>);
}
export interface ModifyReplicationTaskMessage {
  ReplicationTaskArn: string | undefined;
  ReplicationTaskIdentifier?: string;
  MigrationType?: MigrationTypeValue;
  TableMappings?: string;
  ReplicationTaskSettings?: string;
  CdcStartTime?: Date;
  CdcStartPosition?: string;
  CdcStopPosition?: string;
  TaskData?: string;
}
export interface ModifyReplicationTaskResponse {
  ReplicationTask?: ReplicationTask;
}
export interface MoveReplicationTaskMessage {
  ReplicationTaskArn: string | undefined;
  TargetReplicationInstanceArn: string | undefined;
}
export interface MoveReplicationTaskResponse {
  ReplicationTask?: ReplicationTask;
}
export interface RebootReplicationInstanceMessage {
  ReplicationInstanceArn: string | undefined;
  ForceFailover?: boolean;
  ForcePlannedFailover?: boolean;
}
export interface RebootReplicationInstanceResponse {
  ReplicationInstance?: ReplicationInstance;
}
export interface RefreshSchemasMessage {
  EndpointArn: string | undefined;
  ReplicationInstanceArn: string | undefined;
}
export interface RefreshSchemasResponse {
  RefreshSchemasStatus?: RefreshSchemasStatus;
}
export declare const ReloadOptionValue: {
  readonly DATA_RELOAD: "data-reload";
  readonly VALIDATE_ONLY: "validate-only";
};
export type ReloadOptionValue =
  (typeof ReloadOptionValue)[keyof typeof ReloadOptionValue];
export interface TableToReload {
  SchemaName: string | undefined;
  TableName: string | undefined;
}
export interface ReloadReplicationTablesMessage {
  ReplicationConfigArn: string | undefined;
  TablesToReload: TableToReload[] | undefined;
  ReloadOption?: ReloadOptionValue;
}
export interface ReloadReplicationTablesResponse {
  ReplicationConfigArn?: string;
}
export interface ReloadTablesMessage {
  ReplicationTaskArn: string | undefined;
  TablesToReload: TableToReload[] | undefined;
  ReloadOption?: ReloadOptionValue;
}
export interface ReloadTablesResponse {
  ReplicationTaskArn?: string;
}
export interface RemoveTagsFromResourceMessage {
  ResourceArn: string | undefined;
  TagKeys: string[] | undefined;
}
export interface RemoveTagsFromResourceResponse {}
export interface RunFleetAdvisorLsaAnalysisResponse {
  LsaAnalysisId?: string;
  Status?: string;
}
export interface StartExtensionPackAssociationMessage {
  MigrationProjectIdentifier: string | undefined;
}
export interface StartExtensionPackAssociationResponse {
  RequestIdentifier?: string;
}
export interface StartMetadataModelAssessmentMessage {
  MigrationProjectIdentifier: string | undefined;
  SelectionRules: string | undefined;
}
export interface StartMetadataModelAssessmentResponse {
  RequestIdentifier?: string;
}
export interface StartMetadataModelConversionMessage {
  MigrationProjectIdentifier: string | undefined;
  SelectionRules: string | undefined;
}
export interface StartMetadataModelConversionResponse {
  RequestIdentifier?: string;
}
export declare const OriginTypeValue: {
  readonly SOURCE: "SOURCE";
  readonly TARGET: "TARGET";
};
export type OriginTypeValue =
  (typeof OriginTypeValue)[keyof typeof OriginTypeValue];
export interface StartMetadataModelExportAsScriptMessage {
  MigrationProjectIdentifier: string | undefined;
  SelectionRules: string | undefined;
  Origin: OriginTypeValue | undefined;
  FileName?: string;
}
export interface StartMetadataModelExportAsScriptResponse {
  RequestIdentifier?: string;
}
export interface StartMetadataModelExportToTargetMessage {
  MigrationProjectIdentifier: string | undefined;
  SelectionRules: string | undefined;
  OverwriteExtensionPack?: boolean;
}
export interface StartMetadataModelExportToTargetResponse {
  RequestIdentifier?: string;
}
export interface StartMetadataModelImportMessage {
  MigrationProjectIdentifier: string | undefined;
  SelectionRules: string | undefined;
  Origin: OriginTypeValue | undefined;
  Refresh?: boolean;
}
export interface StartMetadataModelImportResponse {
  RequestIdentifier?: string;
}
export interface StartRecommendationsRequest {
  DatabaseId: string | undefined;
  Settings: RecommendationSettings | undefined;
}
export interface StartReplicationMessage {
  ReplicationConfigArn: string | undefined;
  StartReplicationType: string | undefined;
  CdcStartTime?: Date;
  CdcStartPosition?: string;
  CdcStopPosition?: string;
}
export interface StartReplicationResponse {
  Replication?: Replication;
}
export declare const StartReplicationTaskTypeValue: {
  readonly RELOAD_TARGET: "reload-target";
  readonly RESUME_PROCESSING: "resume-processing";
  readonly START_REPLICATION: "start-replication";
};
export type StartReplicationTaskTypeValue =
  (typeof StartReplicationTaskTypeValue)[keyof typeof StartReplicationTaskTypeValue];
export interface StartReplicationTaskMessage {
  ReplicationTaskArn: string | undefined;
  StartReplicationTaskType: StartReplicationTaskTypeValue | undefined;
  CdcStartTime?: Date;
  CdcStartPosition?: string;
  CdcStopPosition?: string;
}
export interface StartReplicationTaskResponse {
  ReplicationTask?: ReplicationTask;
}
export interface StartReplicationTaskAssessmentMessage {
  ReplicationTaskArn: string | undefined;
}
export interface StartReplicationTaskAssessmentResponse {
  ReplicationTask?: ReplicationTask;
}
export declare class KMSFault extends __BaseException {
  readonly name: "KMSFault";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<KMSFault, __BaseException>);
}
export interface StartReplicationTaskAssessmentRunMessage {
  ReplicationTaskArn: string | undefined;
  ServiceAccessRoleArn: string | undefined;
  ResultLocationBucket: string | undefined;
  ResultLocationFolder?: string;
  ResultEncryptionMode?: string;
  ResultKmsKeyArn?: string;
  AssessmentRunName: string | undefined;
  IncludeOnly?: string[];
  Exclude?: string[];
}
export interface StartReplicationTaskAssessmentRunResponse {
  ReplicationTaskAssessmentRun?: ReplicationTaskAssessmentRun;
}
export interface StopReplicationMessage {
  ReplicationConfigArn: string | undefined;
}
export interface StopReplicationResponse {
  Replication?: Replication;
}
export interface StopReplicationTaskMessage {
  ReplicationTaskArn: string | undefined;
}
export interface StopReplicationTaskResponse {
  ReplicationTask?: ReplicationTask;
}
export interface TestConnectionMessage {
  ReplicationInstanceArn: string | undefined;
  EndpointArn: string | undefined;
}
export interface TestConnectionResponse {
  Connection?: Connection;
}
export interface UpdateSubscriptionsToEventBridgeMessage {
  ForceMove?: boolean;
}
export interface UpdateSubscriptionsToEventBridgeResponse {
  Result?: string;
}
export declare const ModifyEndpointMessageFilterSensitiveLog: (
  obj: ModifyEndpointMessage
) => any;
export declare const ModifyEndpointResponseFilterSensitiveLog: (
  obj: ModifyEndpointResponse
) => any;
